..
    DO NOT EDIT
    This file is automatically generated with copier using https://codeberg.org/slidge/legacy-module-template

Features
--------

The table below lists the notable features for matridge.
Refer to `xmpp.org <https://xmpp.org/software/slidge/>`_ for a longer version,
including all XEPs supported by `slidge <https://slidge.im/>`_.

.. doap:: ../../../doap.xml
